/* vsprintf with automatic memory allocation.
   Copyright (C) 2002-2003, 2012, 2015-2016 Free Software Foundation, Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU Lesser General Public License as published by
   the Free Software Foundation; either version 2.1 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

#ifndef _VASPRINTF_H
#define _VASPRINTF_H

/* Get va_list.  */
#include <stdarg.h>

#ifndef __attribute__
/* This feature is available in gcc versions 2.5 and later.  */
# if !__GNUC_PREREQ(2, 5)
#  define __attribute__(Spec) /* empty */
# endif
/* The __-protected variants of 'format' and 'printf' attributes
   are accepted by gcc versions 2.6.4 (effectively 2.7) and later.  */
# if __GNUC__ < 2 || (__GNUC__ == 2 && __GNUC_MINOR__ < 7)
#  define __format__ format
#  define __printf__ printf
# endif
#endif

#ifdef __cplusplus
extern "C" {
#endif

#ifndef DLLX_EXPORT
# if defined(_MSC_VER) || defined(_WIN32) || defined(_DECLSPEC_SUPPORTED)
#  define DLLX_EXPORT __declspec(dllexport)
#  define DLLX_IMPORT __declspec(dllimport)
# elif HAVE_VISIBILITY
#  define DLLX_EXPORT __attribute__((__visibility__("default")))
#  define DLLX_IMPORT
# else
#  define DLLX_EXPORT
#  define DLLX_IMPORT
# endif
#endif

#ifndef LIBASPRINTF_EXPORT
# if defined(IN_LIBASPRINTF)
#  define LIBASPRINTF_EXPORT DLLX_EXPORT
# else
#  define LIBASPRINTF_EXPORT DLLX_IMPORT
# endif
#endif


/* Write formatted output to a string dynamically allocated with malloc().
   If the memory allocation succeeds, store the address of the string in
   *RESULT and return the number of resulting bytes, excluding the trailing
   NUL.  Upon memory allocation error, or some other error, return -1.  */
LIBASPRINTF_EXPORT extern int asprintf (char **result, const char *format, ...)
       __attribute__ ((__format__ (__printf__, 2, 3)));
LIBASPRINTF_EXPORT extern int vasprintf (char **result, const char *format, va_list args)
       __attribute__ ((__format__ (__printf__, 2, 0)));

#ifdef __cplusplus
}
#endif

#endif /* _VASPRINTF_H */
