/* Error handling during reading and writing of PO files.
   Copyright (C) 2004, 2015-2016 Free Software Foundation, Inc.
   Written by Bruno Haible <bruno@clisp.org>, 2004.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */


#ifdef HAVE_CONFIG_H
# include "config.h"
#endif

/* Specification.  */
#include "po-error.h"

#include "error.h"
#include "xerror.h"

static void first_error(int status, int errnum,
                  const char *format, ...)
{
	va_list args;
	
	po_error = error;
	va_start(args, format);
	error_va(status, errnum, format, args);
	va_end(args);
}


LIBGETTEXTSRC_EXPORT void (*po_error) (int status, int errnum,
                  const char *format, ...)
  = first_error;


static void first_error_at_line (int status, int errnum,
                          const char *filename, unsigned int lineno,
                          const char *format, ...)
{
	va_list args;
	
	po_error_at_line = error_at_line;
	va_start(args, format);
	error_at_line_va(status, errnum, filename, lineno, format, args);
	va_end(args);
}

LIBGETTEXTSRC_EXPORT void (*po_error_at_line) (int status, int errnum,
                          const char *filename, unsigned int lineno,
                          const char *format, ...)
  = first_error_at_line;

static void first_multiline_warning(char *prefix, char *message)
{
	po_multiline_warning = multiline_warning;
	po_multiline_warning(prefix, message);
}

LIBGETTEXTSRC_EXPORT void (*po_multiline_warning) (char *prefix, char *message)
  = first_multiline_warning;

static void first_multiline_error(char *prefix, char *message)
{
	po_multiline_error = multiline_error;
	po_multiline_error(prefix, message);
}

LIBGETTEXTSRC_EXPORT void (*po_multiline_error) (char *prefix, char *message)
  = first_multiline_error;
